AlphaMaskU8

Struct AlphaMaskU8 

pub struct AlphaMaskU8<'a, const STEP: usize, const OFFSET: usize, MF: MaskFunction> { /* private fields */ }
Alpha mask with bounds-checked access to a rendering buffer.

STEP is the number of bytes per pixel, OFFSET is the byte offset within each pixel to the mask component.

Port of C++ alpha_mask_u8<Step, Offset, MaskF>.

Implementations

Source

impl<'a, const STEP: usize, const OFFSET: usize, MF: MaskFunction> AlphaMaskU8<'a, STEP, OFFSET, MF>

pub fn new(rbuf: &'a RowAccessor, mask_function: MF) -> Self

pub fn mask_function(&self) -> &MF