WrapMode

Trait WrapMode 

pub trait WrapMode {
    // Required methods
    fn new(size: u32) -> Self;
    fn func(&mut self, v: i32) -> u32;
    fn inc(&mut self) -> u32;
}
Coordinate wrapping mode for tiled image access.

Required Methods

fn new(size: u32) -> Self

Create a wrap mode for the given image dimension.

fn func(&mut self, v: i32) -> u32

Map a coordinate to wrapped output, storing internal state.

fn inc(&mut self) -> u32

Increment the internal state, returning the next wrapped coordinate.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors