pub fn bisectrix(
l1: &LineParameters,
l2: &LineParameters,
x: &mut i32,
y: &mut i32,
)Expand description
Calculate the angle bisector at the junction between two consecutive lines.
Port of C++ bisectrix(). Used for line joins.
pub fn bisectrix(
l1: &LineParameters,
l2: &LineParameters,
x: &mut i32,
y: &mut i32,
)Calculate the angle bisector at the junction between two consecutive lines.
Port of C++ bisectrix(). Used for line joins.