pub fn calc_polygon_area_vd(vertices: &[VertexDist]) -> f64Expand description
Signed area of a polygon defined by a slice of VertexDist.
Same algorithm as calc_polygon_area but works with VertexDist slices
(needed by vcgen_contour).
pub fn calc_polygon_area_vd(vertices: &[VertexDist]) -> f64Signed area of a polygon defined by a slice of VertexDist.
Same algorithm as calc_polygon_area but works with VertexDist slices
(needed by vcgen_contour).