PixfmtGray8

Struct PixfmtGray8 

pub struct PixfmtGray8<'a> { /* private fields */ }
Pixel format for non-premultiplied Gray8 (1 byte per pixel).

Port of C++ pixfmt_alpha_blend_gray<blender_gray<gray8>, rendering_buf, 1, 0>. Each pixel is a single byte representing luminance.

Since there is no alpha channel stored in the buffer, pixel() always returns a=255. Blending uses the source color’s alpha to interpolate the gray value.

Implementations

Source

impl<'a> PixfmtGray8<'a>

pub fn new(rbuf: &'a mut RowAccessor) -> Self

pub fn clear(&mut self, c: &Gray8)

Clear the entire buffer to a solid gray value.