pub struct RasterizerOutlineAa { /* private fields */ }Expand description
Anti-aliased outline rasterizer.
Port of C++ rasterizer_outline_aa<Renderer>.
Builds polylines from vertex sources, then dispatches to the renderer
for AA line drawing with configurable join types.
Implementations
Sourceimpl RasterizerOutlineAa
impl RasterizerOutlineAa
pub fn new() -> Self
pub fn set_line_join(&mut self, join: OutlineAaJoin)
pub fn line_join(&self) -> OutlineAaJoin
pub fn set_round_cap(&mut self, v: bool)
pub fn round_cap(&self) -> bool
pub fn move_to(&mut self, x: i32, y: i32)
pub fn line_to(&mut self, x: i32, y: i32)
pub fn move_to_d(&mut self, x: f64, y: f64)
pub fn line_to_d(&mut self, x: f64, y: f64)
Sourcepub fn add_path<VS: VertexSource, R: OutlineAaRenderer>(
&mut self,
vs: &mut VS,
path_id: u32,
ren: &mut R,
)
pub fn add_path<VS: VertexSource, R: OutlineAaRenderer>( &mut self, vs: &mut VS, path_id: u32, ren: &mut R, )
Add a path from a vertex source and render it.
pub fn render<R: OutlineAaRenderer>(&mut self, ren: &mut R, close_polygon: bool)