RendererOutlineImage

Struct RendererOutlineImage 

pub struct RendererOutlineImage<'a, PF: PixelFormat, P: ImageLinePattern> { /* private fields */ }
Image-patterned outline renderer.

Port of C++ renderer_outline_image<BaseRenderer, ImagePattern>. Renders anti-aliased lines using an image pattern sampled along the stroke.

The generic parameter P is the image line pattern type (e.g., LineImagePattern<PatternFilterBilinearRgba> or LineImagePatternPow2<PatternFilterBilinearRgba>).

Implementations

Source

impl<'a, PF: PixelFormat, P: ImageLinePattern> RendererOutlineImage<'a, PF, P>
where PF::ColorType: Default + Clone + From<Rgba8>,

pub fn new(ren: &'a mut RendererBase<PF>, pattern: &'a P) -> Self

pub fn reset_clipping(&mut self)

pub fn set_clip_box(&mut self, x1: f64, y1: f64, x2: f64, y2: f64)

pub fn set_scale_x(&mut self, s: f64)

pub fn scale_x(&self) -> f64

pub fn set_start_x(&mut self, s: f64)

pub fn start_x(&self) -> f64

pub fn subpixel_width(&self) -> i32

pub fn pattern_width(&self) -> i32

pub fn width(&self) -> f64