ScanlineStorageBin

Struct ScanlineStorageBin 

pub struct ScanlineStorageBin { /* private fields */ }
Binary (non-AA) scanline storage.

Port of C++ scanline_storage_bin. Like ScanlineStorageAa but stores only span extents, no coverage.

Implementations

Source

impl ScanlineStorageBin

pub fn new() -> Self

pub fn prepare(&mut self)

Prepare for new rendering (clear all stored data).

pub fn render_scanline_bin(&mut self, sl: &ScanlineBin)

Store a scanline from a ScanlineBin.

pub fn render_scanline_u8(&mut self, sl: &ScanlineU8)

Store a scanline from any Scanline type (uses add_span with cover_full).

pub fn rewind_scanlines(&mut self) -> bool

Reset the scanline iteration pointer.

pub fn sweep_scanline<SL: Scanline>(&mut self, sl: &mut SL) -> bool

Sweep the next stored scanline into an output scanline container.

pub fn min_x(&self) -> i32

pub fn min_y(&self) -> i32

pub fn max_x(&self) -> i32

pub fn max_y(&self) -> i32

pub fn num_scanlines(&self) -> usize

pub fn scanline_y(&self, idx: usize) -> i32

Get the Y coordinate for a stored scanline by index.

pub fn scanline_num_spans(&self, idx: usize) -> u32

Get the number of spans for a stored scanline.

pub fn embedded_spans( &self, sl_idx: usize, ) -> impl Iterator<Item = EmbeddedBinSpan> + '_

Iterate over embedded spans for boolean algebra.