SpanInterpolatorLinear

Struct SpanInterpolatorLinear 

pub struct SpanInterpolatorLinear<T = TransAffine> { /* private fields */ }
Linear span interpolator.

Transforms span coordinates through a transformation using two DDA interpolators (one for X, one for Y). Transforms only the endpoints and linearly interpolates between them.

Port of C++ span_interpolator_linear<Transformer, SubpixelShift>.

Implementations

Source

impl<T: Transformer> SpanInterpolatorLinear<T>

pub fn new(trans: T) -> Self

pub fn new_begin(trans: T, x: f64, y: f64, len: u32) -> Self

pub fn transformer(&self) -> &T

pub fn set_transformer(&mut self, trans: T)

pub fn begin(&mut self, x: f64, y: f64, len: u32)

Initialize interpolation for a span starting at (x, y) with len pixels.

pub fn resynchronize(&mut self, xe: f64, ye: f64, len: u32)

Re-synchronize interpolation at a new endpoint.

pub fn next(&mut self)

Advance to the next pixel.

pub fn coordinates(&self, x: &mut i32, y: &mut i32)

Get the current transformed coordinates (in subpixel units).