pub trait SpanInterpolator {
// Required methods
fn begin(&mut self, x: f64, y: f64, len: u32);
fn next(&mut self);
fn coordinates(&self, x: &mut i32, y: &mut i32);
}Expand description
Trait for span interpolators used by image filter span generators.
All span interpolators must provide begin, next, and coordinates
methods. This mirrors the C++ template interface used by span generators.
Required Methods
fn begin(&mut self, x: f64, y: f64, len: u32)
fn next(&mut self)
fn coordinates(&self, x: &mut i32, y: &mut i32)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".