pub trait Transformer {
// Required method
fn transform(&self, x: &mut f64, y: &mut f64);
}Expand description
Trait for coordinate transformers used by span interpolators.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T: Transformer> Transformer for &T
Blanket impl: any reference to a Transformer is also a Transformer.
This allows ConvTransform<VS, &TransSinglePath> etc. without cloning.
impl<T: Transformer> Transformer for &T
Blanket impl: any reference to a Transformer is also a Transformer.
This allows ConvTransform<VS, &TransSinglePath> etc. without cloning.