SpanInterpolatorTrans

Struct SpanInterpolatorTrans 

pub struct SpanInterpolatorTrans<T: Transformer> { /* private fields */ }
Per-pixel transform span interpolator.

Transforms every single pixel through the given transformer. This is more accurate than linear interpolation but significantly slower since transform() is called for every pixel rather than just the span endpoints.

Port of C++ span_interpolator_trans<Transformer, SubpixelShift>.

Implementations

Source

impl<T: Transformer> SpanInterpolatorTrans<T>

pub fn new(trans: T) -> Self

pub fn new_begin(trans: T, x: f64, y: f64, len: u32) -> Self

pub fn transformer(&self) -> &T

pub fn set_transformer(&mut self, trans: T)

pub fn begin(&mut self, x: f64, y: f64, _len: u32)

Initialize interpolation for a span starting at (x, y).

pub fn next(&mut self)

Advance to the next pixel.

pub fn coordinates(&self, x: &mut i32, y: &mut i32)

Get the current transformed coordinates (in subpixel units).