Marker placement converter.
Port of agg_conv_marker.h — places marker shapes at positions along a
path, rotating each marker to align with the edge direction.
Structs
- Conv
Marker - Place marker shapes at positions along a path.
Marker placement converter.
Port of agg_conv_marker.h — places marker shapes at positions along a
path, rotating each marker to align with the edge direction.