pub trait ImageSource {
// Required methods
fn span(&mut self, x: i32, y: i32, len: u32) -> &[u8] ⓘ;
fn next_x(&mut self) -> &[u8] ⓘ;
fn next_y(&mut self) -> &[u8] ⓘ;
}Expand description
Trait for image pixel sources used by span image filters.
All image accessor types implement this trait, providing a common interface for the span generators to read pixels.