pub struct LineImagePattern<F: PatternFilter> { /* private fields */ }Expand description
Image pattern for line rendering.
Port of C++ line_image_pattern<Filter>.
Stores a copy of the pattern image extended with dilation borders
for the filter to access neighboring pixels.
Implementations
Sourceimpl<F: PatternFilter> LineImagePattern<F>
impl<F: PatternFilter> LineImagePattern<F>
Sourcepub fn with_source<S: ImagePatternSource>(src: &S) -> Self
pub fn with_source<S: ImagePatternSource>(src: &S) -> Self
Create a pattern initialized from a source.
Sourcepub fn create<S: ImagePatternSource>(&mut self, src: &S)
pub fn create<S: ImagePatternSource>(&mut self, src: &S)
Initialize or reinitialize the pattern from a source image.
Port of C++ line_image_pattern::create.
Sourcepub fn pattern_width(&self) -> i32
pub fn pattern_width(&self) -> i32
Pattern width in subpixel coordinates (for repeating).
Sourcepub fn line_width(&self) -> i32
pub fn line_width(&self) -> i32
Line width in subpixel coordinates (half-height of pattern).