render_scanlines_aa

Function render_scanlines_aa 

pub fn render_scanlines_aa<PF, SG>(
    ras: &mut RasterizerScanlineAa,
    sl: &mut ScanlineU8,
    ren: &mut RendererBase<PF>,
    alloc: &mut SpanAllocator<SG::Color>,
    span_gen: &mut SG,
)
where PF: PixelFormat<ColorType = SG::Color>, SG: SpanGenerator, SG::Color: Default + Clone,
Render all scanlines from the rasterizer using a span generator.

This is the generic rendering function that supports gradients, patterns, and other per-pixel color effects. For each scanline span, the span generator produces an array of colors which are blended into the output.

Port of C++ render_scanlines_aa() (span generator variant).