pub struct SpanInterpolatorLinear<T = TransAffine> { /* private fields */ }Expand description
Linear span interpolator.
Transforms span coordinates through a transformation using two DDA interpolators (one for X, one for Y). Transforms only the endpoints and linearly interpolates between them.
Port of C++ span_interpolator_linear<Transformer, SubpixelShift>.
Implementations
Sourceimpl<T: Transformer> SpanInterpolatorLinear<T>
impl<T: Transformer> SpanInterpolatorLinear<T>
pub fn new(trans: T) -> Self
pub fn new_begin(trans: T, x: f64, y: f64, len: u32) -> Self
pub fn transformer(&self) -> &T
pub fn set_transformer(&mut self, trans: T)
Sourcepub fn begin(&mut self, x: f64, y: f64, len: u32)
pub fn begin(&mut self, x: f64, y: f64, len: u32)
Initialize interpolation for a span starting at (x, y) with len pixels.
Sourcepub fn resynchronize(&mut self, xe: f64, ye: f64, len: u32)
pub fn resynchronize(&mut self, xe: f64, ye: f64, len: u32)
Re-synchronize interpolation at a new endpoint.
Sourcepub fn coordinates(&self, x: &mut i32, y: &mut i32)
pub fn coordinates(&self, x: &mut i32, y: &mut i32)
Get the current transformed coordinates (in subpixel units).